import { useEffect } from '@tarojs/taro';
import { fetchAllOrder } from '@/api/order';
import { AllOrderItem } from '@/types/Order/Order';
import { useSelector, useDispatch } from '@tarojs/redux';
import { OrderStoreState } from './store';
import {
  appendConsumeOrders,
  updateConsumeOrders,
  updateConsumeLastId,
} from './actions';

const useConsumeOrders = (
  customerId: number,
  pageSize: number,
): [AllOrderItem[], () => void, () => void] => {
  const state = useSelector(
    (state: { OrderList: OrderStoreState }) => state.OrderList.consume,
  );
  const dispatch = useDispatch();

  const fetchData = (
    customerId: number,
    lastOrderId: number,
    pageSize: number,
  ) =>
    fetchAllOrder({
      customerId,
      lastOrderId,
      pageSize,
    })
      .then(res => {
        lastOrderId
          ? dispatch(appendConsumeOrders(res.data))
          : dispatch(updateConsumeOrders(res.data));
        return res.data;
      })
      .catch(err => {
        console.log(err);
      });
  const fetchMore = () => {
    let arr = state.consumeOrders;
    const itemIdx = arr.length - 1;
    if (itemIdx >= 0) {
      const orderIdx = arr[itemIdx].data.length - 1;
      if (orderIdx >= 0) {
        dispatch(updateConsumeLastId(arr[itemIdx].data[orderIdx].id));
        return;
      }
    }
    dispatch(updateConsumeLastId(0));
  };
  const resetOrders = () => {
    dispatch(updateConsumeLastId(0));
  };

  useEffect(() => {
    fetchData(customerId, state.lastOrderId, pageSize);
  }, [customerId, state.lastOrderId, pageSize]);

  return [state.consumeOrders, fetchMore, resetOrders];
};

export default useConsumeOrders;
